@@ -274,37 +274,54 @@ class MyWhatify:
 
         return sens[alg]
 
-    # @classmethod
-    # def func_base(cls, func, list_ids):
-    #     for id in list_ids:
-    #         func(id)
-    #
-    # @classmethod
-    # def delete_data_source_by_name(cls, data_name):
-    #     logging.info('deleting data Source with data_name: ' + str(data_name))
-    #     data_id_list = my_toolkit.Datasource.list(search_term=data_name)
-    #     data_id_list = [d['id'] for d in data_id_list['hits']]
-    #     cls.func_base(func=my_toolkit.Datasource.delete, file_id=data_id_list)
-    #     # my_toolkit.Datasource.delete(data_id)
+    @classmethod
+    def search_act_base(cls, searchfunc=None, search_term=None, len=10, action_func=None):
+        delete_list = searchfunc(search_term=search_term, len=len)
+        if delete_list is not None and not delete_list.empty:
+            [action_func(data_id) for data_id in delete_list]
 
     @classmethod
-    def delete_data_source(cls, data_id):
+    def delete_data_source_by_name(cls, data_name=None, len=10):
+        logging.info('deleting data Source with data_name: ' + str(data_name))
+        cls.search_act_base(searchfunc=cls.get_data_source_list, search_term=data_name, len=len,
+                            action_func=my_toolkit.Datasource.delete)
+
+    @classmethod
+    def delete_data_source_by_id(cls, data_id):
         logging.info('deleting data Source data_id: ' + str(data_id))
         # cls.delete_base(func=my_toolkit.Datasource.delete, file_id=data_id)
         my_toolkit.Datasource.delete(data_id)
 
     @classmethod
-    def delete_data_set(cls, data_id):
+    def delete_data_set_by_name(cls, data_name=None, len=10):
+        logging.info('deleting data Source with data_name: ' + str(data_name))
+        cls.func_base(serachfunc=cls.get_datasets_list, search_term=data_name, len=len,
+                      action_func=my_toolkit.Dataset.delete)
+
+    @classmethod
+    def delete_data_set_by_id(cls, data_id):
         logging.info('deleting dataset data_id: ' + str(data_id))
         my_toolkit.Dataset.delete(data_id)
 
     @classmethod
-    def delete_task(cls, task_id):
+    def delete_task_by_name(cls, task_name=None, len=10):
+        logging.info('deleting task with task_name: ' + str(task_name))
+        cls.func_base(serachfunc=cls.get_tasks_list, search_term=task_name, len=len,
+                      action_func=my_toolkit.Task.delete)
+
+    @classmethod
+    def delete_task_by_id(cls, task_id):
         logging.info('deleting task_id: ' + str(task_id))
         my_toolkit.Task.delete(task_id)
 
     @classmethod
-    def delete_prediction(cls, pred_id):
+    def delete_prediction_by_name(cls, prediction_name=None, len=10):
+        logging.info('deleting prediction with prediction_name: ' + str(prediction_name))
+        cls.func_base(serachfunc=cls.get_prediction_list, search_term=prediction_name, len=len,
+                      action_func=my_toolkit.Prediction.delete)
+
+    @classmethod
+    def delete_prediction_id(cls, pred_id):
         logging.info('deleting pred_id: ' + str(pred_id))
         my_toolkit.Prediction.delete(pred_id)
 
@@ -345,7 +362,7 @@ class MyWhatify:
         switcher = {
             'GET': cls.api_get,
             'POST': cls.api_post,
-            'Put': cls.api_put,
+            'PUT': cls.api_put,
             'PATCH': cls.api_patch
         }
         func = switcher.get(method.upper(), lambda: "Invalid api method")
@@ -367,31 +384,43 @@ class MyWhatify:
         with allure.step('validating response json'):
             assert str(expected_payload) == str(response), f"Response is not as expected: {response}, instead of {expected_payload}"
 
+    #############################
+    ###     DATA_SOURCE       ###
+    #############################
     @classmethod
-    def get_data_source(cls, data_name):
+    def get_data_source_by_id(cls, data_id):
+        with allure.step('getting the data source for data ID: ' + str(data_id)):
+            ret_val = my_toolkit.Datasource.list(filter_={'id': [data_id]})['hits']
+            return ret_val[0] if ret_val else {}
+
+    @classmethod
+    def get_data_source_by_name(cls, data_name):
         logging.info('getting the DataSource list for data_name: ' + str(data_name))
-        return my_toolkit.Datasource.list(search_term=data_name)['hits']
+        ret_val = my_toolkit.Datasource.list(search_term=data_name)['hits']
+        return ret_val[0] if ret_val else {}
 
     @classmethod
-    def get_data_source_list(cls, len=10):
+    def get_data_source_list(cls, search_term=None, len=10):
         with allure.step('getting the DataSource list with len: ' + str(len)):
-            list_sources = my_toolkit.Datasource.list()
-            sources = pd.DataFrame(list_sources['hits'])
-
-        return sources[['creation_date', 'data_size', 'id', 'name', 'row_count', 'state', ]].head(len)
+            list_sources = my_toolkit.Datasource.list(search_term=search_term)
+            sources = pd.DataFrame(list_sources['hits'][0:len])
+        return sources[['creation_date', 'data_size', 'id', 'name', 'row_count', 'state']] if not sources.empty else sources
 
     @classmethod
     def get_data_set(cls, data_name):
         logging.info('getting the DataSet list for data_name: ' + str(data_name))
         return my_toolkit.Dataset.list(search_term=data_name)['hits']
 
+    #############################
+    ###        DATASET        ###
+    #############################
     @classmethod
-    def get_datasets_list(cls, len=10):
+    def get_datasets_list(cls, len=10, search_term=None):
         with allure.step('getting the Dataset list with len: ' + str(len)):
-            list_datasets = my_toolkit.Dataset.list()
-            datasets = pd.DataFrame(list_datasets['hits'])
+            list_datasets = my_toolkit.Dataset.list(search_term=search_term)
+            datasets = pd.DataFrame(list_datasets['hits'][0:len])
             datasets.set_index('creation_date')
-        return datasets[['creation_date', 'id', 'name', 'problem_type', 'row_count', 'state']].head(len)
+        return datasets[['creation_date', 'id', 'name', 'problem_type', 'row_count', 'state']]
 
     @classmethod
     def get_tasks(cls, data_name):
@@ -402,8 +431,8 @@ class MyWhatify:
     def get_tasks_list(cls, len=10, search_term=None):
         with allure.step('getting the tasks list with len: ' + str(len)):
             list_tasks = my_toolkit.Task.list(search_term=search_term)
-            tasks = pd.DataFrame(list_tasks['hits'])
-        return tasks[['creation_date', 'dataset_id', 'name', 'notes', 'problem_type', 'state', 'target_metric']].head(len)
+            tasks = pd.DataFrame(list_tasks['hits'][0:len])
+        return tasks[['creation_date', 'dataset_id', 'name', 'notes', 'problem_type', 'state', 'target_metric']]
 
     @classmethod
     def get_ensemble_list(cls, task_id):
@@ -437,9 +466,9 @@ class MyWhatify:
         return ret_list
 
     @classmethod
-    def get_prediction_list(cls, prediction_name):
-        with allure.step('getting the prediction list for the prediction_name: ' + str(prediction_name)):
-            return my_toolkit.Prediction.list(search_term=prediction_name)['hits']
+    def get_prediction_list(cls,  len=10, search_term=None):
+        with allure.step('getting the prediction list for the prediction_name: ' + str(search_term)):
+            return my_toolkit.Prediction.list(search_term=search_term)['hits'][0:len]
 
     @classmethod
     def get_prediction(cls, predict_id, len=None):
